@@ -155,6 +155,8 @@ OptionsDialog::OptionsDialog() {
 	ZLDialogContent &startupTab = myDialog->createTab(ZLResourceKey("Startup"));
 	startupTab.addOption(ZLResourceKey("alwaysStartInLibrary"), fbreader.AlwaysStartInLibraryOption);
 	startupTab.addOption(ZLResourceKey("startFullscreen"), fbreader.StartFullscreenOption);
+	startupTab.addOption(ZLResourceKey("enableToolbar"), fbreader.EnableToolbarOption);
+	startupTab.addOption(ZLResourceKey("enablePopupMenu"), fbreader.EnablePopupMenuOption);
 
 	ZLDialogContent &libraryTab = myDialog->createTab(ZLResourceKey("Library"));
 	Library &library = Library::Instance();
@@ -191,23 +193,23 @@ OptionsDialog::OptionsDialog() {
 				new ZLSimpleBooleanOptionEntry(fbreader.TapScrollingOnFingerOnlyOption);
 			scrollingTab.addOption(ZLResourceKey("fingerOnly"), fingerOnlyEntry);
 			enableTapScrollingEntry->addDependentEntry(fingerOnlyEntry);
-			enableTapScrollingEntry->onStateChanged(enableTapScrollingEntry->initialState());
 		}
 		ZLToggleBooleanOptionEntry *dragOnlyEntry =
 			new ZLToggleBooleanOptionEntry(fbreader.TapScrollingOnDragOnlyOption);
 		scrollingTab.addOption(ZLResourceKey("dragOnly"), dragOnlyEntry);
 		enableTapScrollingEntry->addDependentEntry(dragOnlyEntry);
-		enableTapScrollingEntry->onStateChanged(enableTapScrollingEntry->initialState());
 		ZLToggleBooleanOptionEntry *variableDragEntry =
 			new ZLToggleBooleanOptionEntry(fbreader.VariableDragOption);
 		scrollingTab.addOption(ZLResourceKey("variableDrag"), variableDragEntry);
 		dragOnlyEntry->addDependentEntry(variableDragEntry);
-		dragOnlyEntry->onStateChanged(dragOnlyEntry->initialState());
 		ZLOptionEntry *variableDragLengthEntry =
 			new ZLSimpleSpinOptionEntry(fbreader.VariableDragLengthOption, 100);
 		scrollingTab.addOption(ZLResourceKey("variableDragLength"), variableDragLengthEntry);
 		variableDragEntry->addDependentEntry(variableDragLengthEntry);
+
 		variableDragEntry->onStateChanged(variableDragEntry->initialState());
+		dragOnlyEntry->onStateChanged(dragOnlyEntry->initialState());
+		enableTapScrollingEntry->onStateChanged(enableTapScrollingEntry->initialState());
 	}
 
 	ZLDialogContent &selectionTab = myDialog->createTab(ZLResourceKey("Selection"));
